@@ -18,7 +18,7 @@ class BasePlugin:
 
         :param str name: Identifier by which schema may be referenced
         :param dict definition: Schema definition
-        :param dict kwargs: All additional keywords arguments sent to `APISpec.schema()`
+        :param kwargs: All additional keywords arguments sent to `APISpec.schema()`
         """
         raise PluginMethodNotImplementedError
 
@@ -26,7 +26,7 @@ class BasePlugin:
         """May return response component description as a dict.
 
         :param dict response: Response fields
-        :param dict kwargs: All additional keywords arguments sent to `APISpec.response()`
+        :param kwargs: All additional keywords arguments sent to `APISpec.response()`
         """
         raise PluginMethodNotImplementedError
 
@@ -34,7 +34,7 @@ class BasePlugin:
         """May return parameter component description as a dict.
 
         :param dict parameter: Parameter fields
-        :param dict kwargs: All additional keywords arguments sent to `APISpec.parameter()`
+        :param kwargs: All additional keywords arguments sent to `APISpec.parameter()`
         """
         raise PluginMethodNotImplementedError
 
@@ -47,7 +47,7 @@ class BasePlugin:
         :param list parameters: A `list` of parameters objects or references for the path. See
             https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md#parameterObject
             and https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md#referenceObject
-        :param dict kwargs: All additional keywords arguments sent to `APISpec.path()`
+        :param kwargs: All additional keywords arguments sent to `APISpec.path()`
 
         Return value should be a string or None. If a string is returned, it
         is set as the path.
@@ -64,6 +64,6 @@ class BasePlugin:
         :param str path: Path to the resource
         :param dict operations: A `dict` mapping HTTP methods to operation object.
             See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md#operationObject
-        :param dict kwargs: All additional keywords arguments sent to `APISpec.path()`
+        :param kwargs: All additional keywords arguments sent to `APISpec.path()`
         """
         raise PluginMethodNotImplementedError
